{% if recent_incidents %}
<table>
    <thead>
        <tr>
            <th>Severity</th>
            <th>Summary</th>
            <th>Affected Devices</th>
            <th>Created</th>
        </tr>
    </thead>
    <tbody>
        {% for incident in recent_incidents %}
        <tr>
            <td>
                <span class="badge badge-{{ incident.severity }}">
                    {{ incident.severity.upper() }}
                </span>
            </td>
            <td>
                <a href="/incidents/{{ incident.id }}">{{ incident.summary }}</a>
            </td>
            <td>
                {% if incident.affected_devices %}
                    {{ incident.affected_devices|length }} device(s)
                {% else %}
                    -
                {% endif %}
            </td>
            <td class="time">
                {{ incident.created_at.strftime('%Y-%m-%d %H:%M') }}
            </td>
        </tr>
        {% endfor %}
    </tbody>
</table>
{% else %}
<p style="text-align: center; color: #8b949e; padding: 40px;">
    No recent incidents. Network is healthy! ✓
</p>
{% endif %}
