<div class="tool-result-friendly">
    <div class="result-header">
        <span class="result-title">Baseline Cleared</span>
        <span class="status-pill status-pill-healthy">Done</span>
    </div>

    <div class="issues-card issues-card-healthy">
        <div class="issues-title">{{ data.message }}</div>
        <p>Your baseline data has been reset. Record new samples when your connection is healthy to establish a new baseline.</p>
    </div>
</div>
